@@ -26,8 +26,7 @@ INTERNET_RADIO = "Internet Radio"
 
 
 class Py3status:
-    """
-    """
+    """ """
 
     # available configuration parameters
     cache_timeout = 5
@@ -63,7 +62,7 @@ class Py3status:
             internet_radio = True
 
         if artist and title:
-            now_playing = "{} - {}".format(artist, title)
+            now_playing = f"{artist} - {title}"
         elif artist:
             now_playing = artist
         elif title:
